## Ansættelseskontrakt

Mellem undertegnede

<company-name>Skovly Hotel og Konference ApS</company-name>  
Skovlyvej 14, st., 7950 Erslev  
CVR-nr.: 41123302  
(herefter kaldet virksomheden)

og medundertegnede

Jesper Bach Petersen  
Birkevej 7, 1., 2635 Ishøj  
(herefter kaldet medarbejderen)

indgås følgende ansættelseskontrakt:

<start-date>
## [SECTION-IDX]. Tiltrædelse

Medarbejderen tiltræder ansættelsen pr. 1. juli 2024.
</start-date>

<location>
## [SECTION-IDX]. Arbejdssted og arbejdsopgaver

Arbejdsstedet er Skovlyvej 14, st., 3700 Rønne.

Medarbejderen skal varetage følgende opgaver:

- Modtage gæster
- Håndtere check-in og check-out
- Besvare telefonopkald og e-mails
- Administrative ad hoc-opgaver

Virksomheden er berettiget til at ændre arbejdsopgaverne i overensstemmelse med virksomhedens behov.

<title>
Medarbejderen er ansat som Receptionist.
</title>

<trial-period>
Der er ikke aftalt nogen prøvetid for ansættelsen.
</trial-period>

<salary>
## [SECTION-IDX]. Løn

Den årlige løn udgør kr. 324.000 brutto (før skat, pension og lovpligtige bidrag), svarende til kr. 27.000 pr. måned. Lønnen udbetales bagud den sidste hverdag i måneden til medarbejderens bankkonto.

Lønnen tages op til forhandling én gang årligt.
</salary>

<pension>
## [SECTION-IDX]. Pension

Medarbejderen er omfattet af følgende pensionsordning: Pensam.  
Virksomheden indbetaler et bidrag svarende til 6% af den faste løn, og medarbejderen indbetaler 3% af den faste løn.
</pension>

<social-security>
## [SECTION-IDX]. Sociale sikringsbidrag

Virksomheden indbetaler alle lovpligtige sociale sikringsbidrag, herunder ATP og bidrag til barselsfonden, i henhold til gældende dansk lovgivning.
</social-security>

<work-time>
## [SECTION-IDX]. Arbejdstid

Den gennemsnitlige ugentlige arbejdstid udgør 37 timer. Arbejdstiden placeres inden for virksomhedens normale åbningstid.

Medarbejderen må påregne fleksibilitet, og der ydes ikke særskilt betaling for merarbejde, medmindre dette særskilt aftales med ledelsen.
</work-time>

<holiday>
## [SECTION-IDX]. Ferie

Medarbejderen optjener og afvikler ferie med løn i overensstemmelse med ferielovens regler.

Det særlige ferietillæg udbetales med 1 % af den ferieberettigede løn, medmindre andet følger forskrifter i gældende overenskomst.
</holiday>

<extra-holiday>
## [SECTION-IDX]. Feriefridage

Der ydes ikke ekstra feriefridage ud over de til enhver tid gældende lovregler.
</extra-holiday>

<training>
## [SECTION-IDX]. Efteruddannelse

Medarbejderen har ret til relevant efter- og videreuddannelse efter nærmere aftale og i overensstemmelse med virksomhedens og gældende overenskomsts regler. Efteruddannelse planlægges i samråd med ledelsen.
</training>

<illness>
## [SECTION-IDX]. Sygdom

Ved sygdom skal medarbejderen give virksomheden besked hurtigst muligt.  
Virksomheden kan forlange lægeerklæring ved sygefravær ud over 3 dage, og omkostningen hertil påhviler virksomheden.

Medarbejderen oppebærer sædvanlig løn under sygdom i henhold til funktionærloven og gældende overenskomst.
</illness>

<parental-leave>
## [SECTION-IDX]. Barsel og forældreorlov

Virksomheden yder fuld løn til medarbejderen under barsel og forældreorlov på følgende vilkår:

- Moder: 4 uger før forventet fødsel og 14 uger efter fødslen.
- Fader/medmor: 2 uger efter fødslen.

Orlov og løn under barsel og forældreorlov følger desuden gældende lovgivning og bestemmelserne i kollektiv overenskomst.

Barnets første sygedag: Medarbejderen har ret til én fraværsdag med løn ved barns sygdom pr. barn pr. kalenderår.
</parental-leave>

<termination>
## [SECTION-IDX]. Opsigelse

Ansættelsesforholdet kan af begge parter opsiges med 14 dages varsel til enhver tid, medmindre andet følger gældende overenskomst eller lovgivning.

Opsigelsen skal afgives skriftligt.
</termination>

<collective-agreement>
## [SECTION-IDX]. Kollektiv overenskomst

Ansættelsesforholdet er omfattet af Horesta-overenskomsten, herunder alle relevante løn- og arbejdsforhold reguleret af denne.
</collective-agreement>

## [SECTION-IDX]. Tavshedspligt

Medarbejderen har tavshedspligt under og efter ansættelsen med hensyn til virksomhedens forretningshemmeligheder og øvrige fortrolige oplysninger.   
Overtrædelse kan medføre ansættelsesretlige konsekvenser jf. lov om forretningshemmeligheder.

## [SECTION-IDX]. Retsgrundlag

Dette ansættelsesforhold er underlagt dansk ret. Hvor denne kontrakt ikke foreskriver forhold bedre end lovgivning eller overenskomst, finder funktionær- og ferielovens bestemmelser og øvrig relevant dansk lovgivning anvendelse.

Erslev, den 18.05.2024

Medarbejderen _____________________________________

Virksomheden _____________________________________